.. econpizza documentation master file,
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. include:: ../README.rst

.. toctree::
   :maxdepth: 2

   readme
   quickstart
   tutorial.ipynb
   method.ipynb
   modules
   indices
